@@ -1,11 +1,6 @@
 from datetime import datetime
-from typing import Any
 
-from requests import Session
-
-from ..devices.gateway import Gateway
 from ..exceptions.device import WrongElementError
-from ..mydevolo import Mydevolo
 from .sensor_property import SensorProperty
 
 
@@ -13,26 +8,21 @@ class BinarySensorProperty(SensorProperty):
     """
     Object for binary sensors. It stores the binary sensor state.
 
-    :param gateway: Instance of a Gateway object
-    :param session: Instance of a requests.Session object
-    :param mydevolo: Mydevolo instance for talking to the devolo Cloud
     :param element_uid: Element UID, something like devolo.BinarySensor:hdm:ZWave:CBC56091/24
     :key state: State of the binary sensor
     :type state: bool
     """
 
-    def __init__(self, gateway: Gateway, session: Session, mydevolo: Mydevolo, element_uid: str, **kwargs: Any):
+    def __init__(self, element_uid: str, **kwargs):
         if not element_uid.startswith(("devolo.BinarySensor:",
                                        "devolo.MildewSensor:",
                                        "devolo.ShutterMovementFI:",
-                                       "devolo.WarningBinaryFI:",)):
+                                       "devolo.WarningBinaryFI:")):
             raise WrongElementError(f"{element_uid} is not a Binary Sensor.")
 
-        self._state = False
-        self.state = kwargs.get("state", False)
-
-        super().__init__(gateway=gateway, session=session, mydevolo=mydevolo, element_uid=element_uid, **kwargs)
+        super().__init__(element_uid=element_uid, **kwargs)
 
+        self._state = kwargs.pop("state", False)
 
     @property
     def last_activity(self) -> datetime:
@@ -44,7 +34,7 @@ class BinarySensorProperty(SensorProperty):
         """ The gateway persists the last activity of some binary sensors. They can be initialized with that value. """
         if timestamp != -1:
             self._last_activity = datetime.utcfromtimestamp(timestamp / 1000)
-            self._logger.debug(f"self.last_activity of element_uid {self.element_uid} set to {self._last_activity}.")
+            self._logger.debug("last_activity of element_uid %s set to %s.", self.element_uid, self._last_activity)
 
     @property
     def state(self) -> bool:
@@ -56,3 +46,4 @@ class BinarySensorProperty(SensorProperty):
         """ Update state of the binary sensor and set point in time of the last_activity. """
         self._state = state
         self._last_activity = datetime.now()
+        self._logger.debug("state of element_uid %s set to %s.", self.element_uid, state)
