@@ -5,6 +5,17 @@ import pytest
 @pytest.mark.usefixtures("home_control_instance")
 class TestPublisher:
 
+    def test_add_event(self):
+        self.homecontrol.publisher.add_event("Test")
+        assert "Test" in self.homecontrol.publisher._events
+
+    def test_delete_event(self):
+        self.homecontrol.publisher._events = {
+            "Test": {}
+        }
+        self.homecontrol.publisher.delete_event("Test")
+        assert "Test" not in self.homecontrol.publisher._events
+
     def test_register_unregister(self):
         for device in self.homecontrol.devices:
             self.homecontrol.devices[device].subscriber = Subscriber(device)
@@ -22,8 +33,8 @@ class TestPublisher:
             self.homecontrol.publisher.dispatch(event="hdm:ZWave:F6BF9812/4", message=())
 
 
-
 class Subscriber:
+
     def __init__(self, name):
         self.name = name
 
